@@ -152,12 +152,13 @@ sub download_file {
 	
 	$options -> {type} .= '; charset=' . $options -> {charset} if $options -> {charset};
 
-	$r -> content_type ($options -> {type});
-	$options -> {no_force_download} or $r -> header_out ('Content-Disposition' => "attachment;filename=" . $options -> {file_name}); #if $options -> {file_name};
-	$r -> send_http_header ();
-
 	my $path = $r -> document_root . $options -> {path};
 
+	$r -> content_type ($options -> {type});
+	$options -> {no_force_download} or $r -> header_out ('Content-Disposition' => "attachment;filename=" . $options -> {file_name}); 
+	$r -> header_out ('Content-Length' => -s $path);
+	$r -> send_http_header ();
+
 	open (F, $path) or die ("Can't open file $path: $!");
 
 	$r -> send_fd (F);
@@ -209,4 +210,14 @@ sub upload_file {
 	
 }
 
+################################################################################
+
+sub add_vocabularies {
+
+	my ($item, @names) = @_;
+	
+	map {$item -> {$_} = sql_select_vocabulary ($_)} @names;
+
+}
+
 1;
\ No newline at end of file
